@@ -1,4 +1,4 @@
-/* $Id: events.h,v 1.2 2004/03/12 21:03:12 thrulliq Exp $ */
+/* $Id: events.h,v 1.3 2004/05/05 15:59:59 thrulliq Exp $ */
 
 #ifndef _EVENTS_H_
 #define _EVENTS_H_
@@ -15,7 +15,8 @@ enum {
 	GNOCKY_EVENT_WRITE_BITMAP,
 	GNOCKY_EVENT_READ_SMS_LIST,
 	GNOCKY_EVENT_SEND_SMS,
-	GNOCKY_EVENT_DELETE_SMS
+	GNOCKY_EVENT_DELETE_SMS,
+	GNOCKY_EVENT_TERMINATE = 0xffff
 };
 
 #endif
