@@ -1,4 +1,4 @@
-/* $Id: monitor.c,v 1.10 2004/03/14 20:43:05 thrulliq Exp $ */
+/* $Id: monitor.c,v 1.15 2004/07/07 16:33:11 thrulliq Exp $ */
 
 /*
  *	Everything here runs in thread. So beware ;-)
@@ -30,6 +30,7 @@ gboolean sms_updated = FALSE;
 struct gn_statemachine statemachine;
 static char *bindir;
 
+static
 void gnocky_monitor_init()
 {
 	memset(&pm, 0, sizeof(pm));
@@ -391,6 +392,13 @@ static gn_error gnocky_write_bitmap(gn_bmp_types type)
 	return error;
 }
 
+static void gnocky_free_sms_entry(gpointer data, gpointer user_data)
+{
+	gn_sms *sms = data;
+
+	g_free(sms);
+}
+
 static gn_error gnocky_read_sms_list()
 {
 	gn_error error = GN_ERR_NONE;
@@ -405,6 +413,7 @@ static gn_error gnocky_read_sms_list()
 	g_mutex_lock(sms_mutex);
 
 	sms_updated = TRUE;
+	g_slist_foreach(sms_list, gnocky_free_sms_entry, NULL);
 	g_slist_free(sms_list);
 	sms_list = NULL;
 	
@@ -519,6 +528,17 @@ static gn_error gnocky_delete_sms(gn_sms *sms)
 	return error;
 }
 
+static 
+void gnocky_monitor_terminate()
+{
+	gn_error error;
+	
+	gnocky_statusbar_set_text(_("Closing link..."));
+	error = gn_sm_functions(GN_OP_Terminate, NULL, &statemachine);
+	pm.link_status = GNOCKY_LINK_IDLE;
+	g_thread_exit(NULL);
+}
+
 static gn_error gnocky_execute_event(GnockyEvent *ev)
 {
 	gn_error error = GN_ERR_NONE;
@@ -558,6 +578,9 @@ static gn_error gnocky_execute_event(GnockyEvent *ev)
 			break;
 		case GNOCKY_EVENT_NONE:
 			break;
+		case GNOCKY_EVENT_TERMINATE:
+			gnocky_monitor_terminate();
+			break;
 		default:
 			g_print("UNKNOWN EVENT\n");
 			break;
@@ -621,13 +644,14 @@ gn_error monitor_initialise_link()
 	if (!phonebook_mutex)
 		gnocky_monitor_init();
 	
-	if (gn_cfg_read(&bindir) < 0) {
-		gnocky_show_error(_("Cannot read configuration file! Please check ~/.gnokiirc"));
+	if (gn_cfg_read_default() < 0) {
+		gnocky_show_error_from_thread(_("Cannot read configuration file! Please check ~/.gnokiirc"));
 		return GN_ERR_UNKNOWN;
 	}
 
 	if (!gn_cfg_phone_load("", &statemachine)) {
-		gnocky_show_error(_("Cannot load phone!"));
+		gnocky_statusbar_set_text(_("Cannot load phone!"));
+		sleep(2);
 		return GN_ERR_UNKNOWN;
 	}
 
@@ -661,14 +685,15 @@ gpointer gnocky_monitor_loop(gpointer user_data)
 	while (1) {
 		if (pm.link_status != GNOCKY_LINK_CONNECTED) {
 			if ((error = monitor_initialise_link()) != GN_ERR_NONE) {
-				//gnocky_show_error_from_thread(gn_error_print(error));
 				pm.link_status = GNOCKY_LINK_FAILED;
 				gnocky_statusbar_set_text(_("Connection failed!"));
 				gn_sm_functions(GN_OP_Terminate, NULL, &statemachine);
+				gnocky_set_button_active(FALSE);
 				sleep(1);
-			} else
+			} else {
 				pm.link_status = GNOCKY_LINK_CONNECTED;
-
+				gnocky_set_button_active(TRUE);
+			}
 		}
 		g_get_current_time(&tv);
 		tv.tv_sec += 3;
@@ -690,6 +715,7 @@ gpointer gnocky_monitor_loop(gpointer user_data)
 				pm.link_status = GNOCKY_LINK_FAILED;
 				gnocky_statusbar_set_text(_("Connection broken!"));
 				gn_sm_functions(GN_OP_Terminate, NULL, &statemachine);
+				gnocky_set_button_active(FALSE);
 				continue;
 			}
 		} else {
@@ -730,7 +756,7 @@ gpointer gnocky_monitor_loop(gpointer user_data)
 void gnocky_monitor_create()
 {
 	gnocky_monitor_init();
-	monitor = g_thread_create((GThreadFunc) gnocky_monitor_loop, NULL, FALSE, NULL);
+	monitor = g_thread_create((GThreadFunc) gnocky_monitor_loop, NULL, TRUE, NULL);
 }
 
 void gnocky_monitor_destroy()
